# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 15.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V61
0
40
42
91
92
93
94
123
124
125
126
3898
3902
5787
5789
8261
8263
8317
8319
8333
8335
8968
8972
9001
9003
10088
10102
10181
10183
10214
10224
10627
10649
10712
10716
10748
10750
11810
11818
11861
11869
12296
12306
12308
12316
65113
65119
65288
65290
65339
65340
65341
65342
65371
65372
65373
65374
65375
65377
65378
65380
END
