# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 15.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V40
173
174
1536
1542
1564
1565
1757
1758
1807
1808
2192
2194
2274
2275
6158
6159
8206
8208
8234
8239
8288
8293
8294
8304
65279
65280
65529
65532
69821
69822
69837
69838
78896
78912
113824
113828
119155
119163
917505
917506
END
