# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 15.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'ToGc'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'ToGc'}{'missing'} = 'Cn';

return <<'END';
0	1F	Cc
20		Zs
21	23	Po
24		Sc
25	27	Po
28		Ps
29		Pe
2A		Po
2B		Sm
2C		Po
2D		Pd
2E	2F	Po
30	39	Nd
3A	3B	Po
3C	3E	Sm
3F	40	Po
41	5A	Lu
5B		Ps
5C		Po
5D		Pe
5E		Sk
5F		Pc
60		Sk
61	7A	Ll
7B		Ps
7C		Sm
7D		Pe
7E		Sm
7F	9F	Cc
A0		Zs
A1		Po
A2	A5	Sc
A6		So
A7		Po
A8		Sk
A9		So
AA		Lo
AB		Pi
AC		Sm
AD		Cf
AE		So
AF		Sk
B0		So
B1		Sm
B2	B3	No
B4		Sk
B5		Ll
B6	B7	Po
B8		Sk
B9		No
BA		Lo
BB		Pf
BC	BE	No
BF		Po
C0	D6	Lu
D7		Sm
D8	DE	Lu
DF	F6	Ll
F7		Sm
F8	FF	Ll
100		Lu
101		Ll
102		Lu
103		Ll
104		Lu
105		Ll
106		Lu
107		Ll
108		Lu
109		Ll
10A		Lu
10B		Ll
10C		Lu
10D		Ll
10E		Lu
10F		Ll
110		Lu
111		Ll
112		Lu
113		Ll
114		Lu
115		Ll
116		Lu
117		Ll
118		Lu
119		Ll
11A		Lu
11B		Ll
11C		Lu
11D		Ll
11E		Lu
11F		Ll
120		Lu
121		Ll
122		Lu
123		Ll
124		Lu
125		Ll
126		Lu
127		Ll
128		Lu
129		Ll
12A		Lu
12B		Ll
12C		Lu
12D		Ll
12E		Lu
12F		Ll
130		Lu
131		Ll
132		Lu
133		Ll
134		Lu
135		Ll
136		Lu
137	138	Ll
139		Lu
13A		Ll
13B		Lu
13C		Ll
13D		Lu
13E		Ll
13F		Lu
140		Ll
141		Lu
142		Ll
143		Lu
144		Ll
145		Lu
146		Ll
147		Lu
148	149	Ll
14A		Lu
14B		Ll
14C		Lu
14D		Ll
14E		Lu
14F		Ll
150		Lu
151		Ll
152		Lu
153		Ll
154		Lu
155		Ll
156		Lu
157		Ll
158		Lu
159		Ll
15A		Lu
15B		Ll
15C		Lu
15D		Ll
15E		Lu
15F		Ll
160		Lu
161		Ll
162		Lu
163		Ll
164		Lu
165		Ll
166		Lu
167		Ll
168		Lu
169		Ll
16A		Lu
16B		Ll
16C		Lu
16D		Ll
16E		Lu
16F		Ll
170		Lu
171		Ll
172		Lu
173		Ll
174		Lu
175		Ll
176		Lu
177		Ll
178	179	Lu
17A		Ll
17B		Lu
17C		Ll
17D		Lu
17E	180	Ll
181	182	Lu
183		Ll
184		Lu
185		Ll
186	187	Lu
188		Ll
189	18B	Lu
18C	18D	Ll
18E	191	Lu
192		Ll
193	194	Lu
195		Ll
196	198	Lu
199	19B	Ll
19C	19D	Lu
19E		Ll
19F	1A0	Lu
1A1		Ll
1A2		Lu
1A3		Ll
1A4		Lu
1A5		Ll
1A6	1A7	Lu
1A8		Ll
1A9		Lu
1AA	1AB	Ll
1AC		Lu
1AD		Ll
1AE	1AF	Lu
1B0		Ll
1B1	1B3	Lu
1B4		Ll
1B5		Lu
1B6		Ll
1B7	1B8	Lu
1B9	1BA	Ll
1BB		Lo
1BC		Lu
1BD	1BF	Ll
1C0	1C3	Lo
1C4		Lu
1C5		Lt
1C6		Ll
1C7		Lu
1C8		Lt
1C9		Ll
1CA		Lu
1CB		Lt
1CC		Ll
1CD		Lu
1CE		Ll
1CF		Lu
1D0		Ll
1D1		Lu
1D2		Ll
1D3		Lu
1D4		Ll
1D5		Lu
1D6		Ll
1D7		Lu
1D8		Ll
1D9		Lu
1DA		Ll
1DB		Lu
1DC	1DD	Ll
1DE		Lu
1DF		Ll
1E0		Lu
1E1		Ll
1E2		Lu
1E3		Ll
1E4		Lu
1E5		Ll
1E6		Lu
1E7		Ll
1E8		Lu
1E9		Ll
1EA		Lu
1EB		Ll
1EC		Lu
1ED		Ll
1EE		Lu
1EF	1F0	Ll
1F1		Lu
1F2		Lt
1F3		Ll
1F4		Lu
1F5		Ll
1F6	1F8	Lu
1F9		Ll
1FA		Lu
1FB		Ll
1FC		Lu
1FD		Ll
1FE		Lu
1FF		Ll
200		Lu
201		Ll
202		Lu
203		Ll
204		Lu
205		Ll
206		Lu
207		Ll
208		Lu
209		Ll
20A		Lu
20B		Ll
20C		Lu
20D		Ll
20E		Lu
20F		Ll
210		Lu
211		Ll
212		Lu
213		Ll
214		Lu
215		Ll
216		Lu
217		Ll
218		Lu
219		Ll
21A		Lu
21B		Ll
21C		Lu
21D		Ll
21E		Lu
21F		Ll
220		Lu
221		Ll
222		Lu
223		Ll
224		Lu
225		Ll
226		Lu
227		Ll
228		Lu
229		Ll
22A		Lu
22B		Ll
22C		Lu
22D		Ll
22E		Lu
22F		Ll
230		Lu
231		Ll
232		Lu
233	239	Ll
23A	23B	Lu
23C		Ll
23D	23E	Lu
23F	240	Ll
241		Lu
242		Ll
243	246	Lu
247		Ll
248		Lu
249		Ll
24A		Lu
24B		Ll
24C		Lu
24D		Ll
24E		Lu
24F	293	Ll
294		Lo
295	2AF	Ll
2B0	2C1	Lm
2C2	2C5	Sk
2C6	2D1	Lm
2D2	2DF	Sk
2E0	2E4	Lm
2E5	2EB	Sk
2EC		Lm
2ED		Sk
2EE		Lm
2EF	2FF	Sk
300	36F	Mn
370		Lu
371		Ll
372		Lu
373		Ll
374		Lm
375		Sk
376		Lu
377		Ll
37A		Lm
37B	37D	Ll
37E		Po
37F		Lu
384	385	Sk
386		Lu
387		Po
388	38A	Lu
38C		Lu
38E	38F	Lu
390		Ll
391	3A1	Lu
3A3	3AB	Lu
3AC	3CE	Ll
3CF		Lu
3D0	3D1	Ll
3D2	3D4	Lu
3D5	3D7	Ll
3D8		Lu
3D9		Ll
3DA		Lu
3DB		Ll
3DC		Lu
3DD		Ll
3DE		Lu
3DF		Ll
3E0		Lu
3E1		Ll
3E2		Lu
3E3		Ll
3E4		Lu
3E5		Ll
3E6		Lu
3E7		Ll
3E8		Lu
3E9		Ll
3EA		Lu
3EB		Ll
3EC		Lu
3ED		Ll
3EE		Lu
3EF	3F3	Ll
3F4		Lu
3F5		Ll
3F6		Sm
3F7		Lu
3F8		Ll
3F9	3FA	Lu
3FB	3FC	Ll
3FD	42F	Lu
430	45F	Ll
460		Lu
461		Ll
462		Lu
463		Ll
464		Lu
465		Ll
466		Lu
467		Ll
468		Lu
469		Ll
46A		Lu
46B		Ll
46C		Lu
46D		Ll
46E		Lu
46F		Ll
470		Lu
471		Ll
472		Lu
473		Ll
474		Lu
475		Ll
476		Lu
477		Ll
478		Lu
479		Ll
47A		Lu
47B		Ll
47C		Lu
47D		Ll
47E		Lu
47F		Ll
480		Lu
481		Ll
482		So
483	487	Mn
488	489	Me
48A		Lu
48B		Ll
48C		Lu
48D		Ll
48E		Lu
48F		Ll
490		Lu
491		Ll
492		Lu
493		Ll
494		Lu
495		Ll
496		Lu
497		Ll
498		Lu
499		Ll
49A		Lu
49B		Ll
49C		Lu
49D		Ll
49E		Lu
49F		Ll
4A0		Lu
4A1		Ll
4A2		Lu
4A3		Ll
4A4		Lu
4A5		Ll
4A6		Lu
4A7		Ll
4A8		Lu
4A9		Ll
4AA		Lu
4AB		Ll
4AC		Lu
4AD		Ll
4AE		Lu
4AF		Ll
4B0		Lu
4B1		Ll
4B2		Lu
4B3		Ll
4B4		Lu
4B5		Ll
4B6		Lu
4B7		Ll
4B8		Lu
4B9		Ll
4BA		Lu
4BB		Ll
4BC		Lu
4BD		Ll
4BE		Lu
4BF		Ll
4C0	4C1	Lu
4C2		Ll
4C3		Lu
4C4		Ll
4C5		Lu
4C6		Ll
4C7		Lu
4C8		Ll
4C9		Lu
4CA		Ll
4CB		Lu
4CC		Ll
4CD		Lu
4CE	4CF	Ll
4D0		Lu
4D1		Ll
4D2		Lu
4D3		Ll
4D4		Lu
4D5		Ll
4D6		Lu
4D7		Ll
4D8		Lu
4D9		Ll
4DA		Lu
4DB		Ll
4DC		Lu
4DD		Ll
4DE		Lu
4DF		Ll
4E0		Lu
4E1		Ll
4E2		Lu
4E3		Ll
4E4		Lu
4E5		Ll
4E6		Lu
4E7		Ll
4E8		Lu
4E9		Ll
4EA		Lu
4EB		Ll
4EC		Lu
4ED		Ll
4EE		Lu
4EF		Ll
4F0		Lu
4F1		Ll
4F2		Lu
4F3		Ll
4F4		Lu
4F5		Ll
4F6		Lu
4F7		Ll
4F8		Lu
4F9		Ll
4FA		Lu
4FB		Ll
4FC		Lu
4FD		Ll
4FE		Lu
4FF		Ll
500		Lu
501		Ll
502		Lu
503		Ll
504		Lu
505		Ll
506		Lu
507		Ll
508		Lu
509		Ll
50A		Lu
50B		Ll
50C		Lu
50D		Ll
50E		Lu
50F		Ll
510		Lu
511		Ll
512		Lu
513		Ll
514		Lu
515		Ll
516		Lu
517		Ll
518		Lu
519		Ll
51A		Lu
51B		Ll
51C		Lu
51D		Ll
51E		Lu
51F		Ll
520		Lu
521		Ll
522		Lu
523		Ll
524		Lu
525		Ll
526		Lu
527		Ll
528		Lu
529		Ll
52A		Lu
52B		Ll
52C		Lu
52D		Ll
52E		Lu
52F		Ll
531	556	Lu
559		Lm
55A	55F	Po
560	588	Ll
589		Po
58A		Pd
58D	58E	So
58F		Sc
591	5BD	Mn
5BE		Pd
5BF		Mn
5C0		Po
5C1	5C2	Mn
5C3		Po
5C4	5C5	Mn
5C6		Po
5C7		Mn
5D0	5EA	Lo
5EF	5F2	Lo
5F3	5F4	Po
600	605	Cf
606	608	Sm
609	60A	Po
60B		Sc
60C	60D	Po
60E	60F	So
610	61A	Mn
61B		Po
61C		Cf
61D	61F	Po
620	63F	Lo
640		Lm
641	64A	Lo
64B	65F	Mn
660	669	Nd
66A	66D	Po
66E	66F	Lo
670		Mn
671	6D3	Lo
6D4		Po
6D5		Lo
6D6	6DC	Mn
6DD		Cf
6DE		So
6DF	6E4	Mn
6E5	6E6	Lm
6E7	6E8	Mn
6E9		So
6EA	6ED	Mn
6EE	6EF	Lo
6F0	6F9	Nd
6FA	6FC	Lo
6FD	6FE	So
6FF		Lo
700	70D	Po
70F		Cf
710		Lo
711		Mn
712	72F	Lo
730	74A	Mn
74D	7A5	Lo
7A6	7B0	Mn
7B1		Lo
7C0	7C9	Nd
7CA	7EA	Lo
7EB	7F3	Mn
7F4	7F5	Lm
7F6		So
7F7	7F9	Po
7FA		Lm
7FD		Mn
7FE	7FF	Sc
800	815	Lo
816	819	Mn
81A		Lm
81B	823	Mn
824		Lm
825	827	Mn
828		Lm
829	82D	Mn
830	83E	Po
840	858	Lo
859	85B	Mn
85E		Po
860	86A	Lo
870	887	Lo
888		Sk
889	88E	Lo
890	891	Cf
898	89F	Mn
8A0	8C8	Lo
8C9		Lm
8CA	8E1	Mn
8E2		Cf
8E3	902	Mn
903		Mc
904	939	Lo
93A		Mn
93B		Mc
93C		Mn
93D		Lo
93E	940	Mc
941	948	Mn
949	94C	Mc
94D		Mn
94E	94F	Mc
950		Lo
951	957	Mn
958	961	Lo
962	963	Mn
964	965	Po
966	96F	Nd
970		Po
971		Lm
972	980	Lo
981		Mn
982	983	Mc
985	98C	Lo
98F	990	Lo
993	9A8	Lo
9AA	9B0	Lo
9B2		Lo
9B6	9B9	Lo
9BC		Mn
9BD		Lo
9BE	9C0	Mc
9C1	9C4	Mn
9C7	9C8	Mc
9CB	9CC	Mc
9CD		Mn
9CE		Lo
9D7		Mc
9DC	9DD	Lo
9DF	9E1	Lo
9E2	9E3	Mn
9E6	9EF	Nd
9F0	9F1	Lo
9F2	9F3	Sc
9F4	9F9	No
9FA		So
9FB		Sc
9FC		Lo
9FD		Po
9FE		Mn
A01	A02	Mn
A03		Mc
A05	A0A	Lo
A0F	A10	Lo
A13	A28	Lo
A2A	A30	Lo
A32	A33	Lo
A35	A36	Lo
A38	A39	Lo
A3C		Mn
A3E	A40	Mc
A41	A42	Mn
A47	A48	Mn
A4B	A4D	Mn
A51		Mn
A59	A5C	Lo
A5E		Lo
A66	A6F	Nd
A70	A71	Mn
A72	A74	Lo
A75		Mn
A76		Po
A81	A82	Mn
A83		Mc
A85	A8D	Lo
A8F	A91	Lo
A93	AA8	Lo
AAA	AB0	Lo
AB2	AB3	Lo
AB5	AB9	Lo
ABC		Mn
ABD		Lo
ABE	AC0	Mc
AC1	AC5	Mn
AC7	AC8	Mn
AC9		Mc
ACB	ACC	Mc
ACD		Mn
AD0		Lo
AE0	AE1	Lo
AE2	AE3	Mn
AE6	AEF	Nd
AF0		Po
AF1		Sc
AF9		Lo
AFA	AFF	Mn
B01		Mn
B02	B03	Mc
B05	B0C	Lo
B0F	B10	Lo
B13	B28	Lo
B2A	B30	Lo
B32	B33	Lo
B35	B39	Lo
B3C		Mn
B3D		Lo
B3E		Mc
B3F		Mn
B40		Mc
B41	B44	Mn
B47	B48	Mc
B4B	B4C	Mc
B4D		Mn
B55	B56	Mn
B57		Mc
B5C	B5D	Lo
B5F	B61	Lo
B62	B63	Mn
B66	B6F	Nd
B70		So
B71		Lo
B72	B77	No
B82		Mn
B83		Lo
B85	B8A	Lo
B8E	B90	Lo
B92	B95	Lo
B99	B9A	Lo
B9C		Lo
B9E	B9F	Lo
BA3	BA4	Lo
BA8	BAA	Lo
BAE	BB9	Lo
BBE	BBF	Mc
BC0		Mn
BC1	BC2	Mc
BC6	BC8	Mc
BCA	BCC	Mc
BCD		Mn
BD0		Lo
BD7		Mc
BE6	BEF	Nd
BF0	BF2	No
BF3	BF8	So
BF9		Sc
BFA		So
C00		Mn
C01	C03	Mc
C04		Mn
C05	C0C	Lo
C0E	C10	Lo
C12	C28	Lo
C2A	C39	Lo
C3C		Mn
C3D		Lo
C3E	C40	Mn
C41	C44	Mc
C46	C48	Mn
C4A	C4D	Mn
C55	C56	Mn
C58	C5A	Lo
C5D		Lo
C60	C61	Lo
C62	C63	Mn
C66	C6F	Nd
C77		Po
C78	C7E	No
C7F		So
C80		Lo
C81		Mn
C82	C83	Mc
C84		Po
C85	C8C	Lo
C8E	C90	Lo
C92	CA8	Lo
CAA	CB3	Lo
CB5	CB9	Lo
CBC		Mn
CBD		Lo
CBE		Mc
CBF		Mn
CC0	CC4	Mc
CC6		Mn
CC7	CC8	Mc
CCA	CCB	Mc
CCC	CCD	Mn
CD5	CD6	Mc
CDD	CDE	Lo
CE0	CE1	Lo
CE2	CE3	Mn
CE6	CEF	Nd
CF1	CF2	Lo
CF3		Mc
D00	D01	Mn
D02	D03	Mc
D04	D0C	Lo
D0E	D10	Lo
D12	D3A	Lo
D3B	D3C	Mn
D3D		Lo
D3E	D40	Mc
D41	D44	Mn
D46	D48	Mc
D4A	D4C	Mc
D4D		Mn
D4E		Lo
D4F		So
D54	D56	Lo
D57		Mc
D58	D5E	No
D5F	D61	Lo
D62	D63	Mn
D66	D6F	Nd
D70	D78	No
D79		So
D7A	D7F	Lo
D81		Mn
D82	D83	Mc
D85	D96	Lo
D9A	DB1	Lo
DB3	DBB	Lo
DBD		Lo
DC0	DC6	Lo
DCA		Mn
DCF	DD1	Mc
DD2	DD4	Mn
DD6		Mn
DD8	DDF	Mc
DE6	DEF	Nd
DF2	DF3	Mc
DF4		Po
E01	E30	Lo
E31		Mn
E32	E33	Lo
E34	E3A	Mn
E3F		Sc
E40	E45	Lo
E46		Lm
E47	E4E	Mn
E4F		Po
E50	E59	Nd
E5A	E5B	Po
E81	E82	Lo
E84		Lo
E86	E8A	Lo
E8C	EA3	Lo
EA5		Lo
EA7	EB0	Lo
EB1		Mn
EB2	EB3	Lo
EB4	EBC	Mn
EBD		Lo
EC0	EC4	Lo
EC6		Lm
EC8	ECE	Mn
ED0	ED9	Nd
EDC	EDF	Lo
F00		Lo
F01	F03	So
F04	F12	Po
F13		So
F14		Po
F15	F17	So
F18	F19	Mn
F1A	F1F	So
F20	F29	Nd
F2A	F33	No
F34		So
F35		Mn
F36		So
F37		Mn
F38		So
F39		Mn
F3A		Ps
F3B		Pe
F3C		Ps
F3D		Pe
F3E	F3F	Mc
F40	F47	Lo
F49	F6C	Lo
F71	F7E	Mn
F7F		Mc
F80	F84	Mn
F85		Po
F86	F87	Mn
F88	F8C	Lo
F8D	F97	Mn
F99	FBC	Mn
FBE	FC5	So
FC6		Mn
FC7	FCC	So
FCE	FCF	So
FD0	FD4	Po
FD5	FD8	So
FD9	FDA	Po
1000	102A	Lo
102B	102C	Mc
102D	1030	Mn
1031		Mc
1032	1037	Mn
1038		Mc
1039	103A	Mn
103B	103C	Mc
103D	103E	Mn
103F		Lo
1040	1049	Nd
104A	104F	Po
1050	1055	Lo
1056	1057	Mc
1058	1059	Mn
105A	105D	Lo
105E	1060	Mn
1061		Lo
1062	1064	Mc
1065	1066	Lo
1067	106D	Mc
106E	1070	Lo
1071	1074	Mn
1075	1081	Lo
1082		Mn
1083	1084	Mc
1085	1086	Mn
1087	108C	Mc
108D		Mn
108E		Lo
108F		Mc
1090	1099	Nd
109A	109C	Mc
109D		Mn
109E	109F	So
10A0	10C5	Lu
10C7		Lu
10CD		Lu
10D0	10FA	Ll
10FB		Po
10FC		Lm
10FD	10FF	Ll
1100	1248	Lo
124A	124D	Lo
1250	1256	Lo
1258		Lo
125A	125D	Lo
1260	1288	Lo
128A	128D	Lo
1290	12B0	Lo
12B2	12B5	Lo
12B8	12BE	Lo
12C0		Lo
12C2	12C5	Lo
12C8	12D6	Lo
12D8	1310	Lo
1312	1315	Lo
1318	135A	Lo
135D	135F	Mn
1360	1368	Po
1369	137C	No
1380	138F	Lo
1390	1399	So
13A0	13F5	Lu
13F8	13FD	Ll
1400		Pd
1401	166C	Lo
166D		So
166E		Po
166F	167F	Lo
1680		Zs
1681	169A	Lo
169B		Ps
169C		Pe
16A0	16EA	Lo
16EB	16ED	Po
16EE	16F0	Nl
16F1	16F8	Lo
1700	1711	Lo
1712	1714	Mn
1715		Mc
171F	1731	Lo
1732	1733	Mn
1734		Mc
1735	1736	Po
1740	1751	Lo
1752	1753	Mn
1760	176C	Lo
176E	1770	Lo
1772	1773	Mn
1780	17B3	Lo
17B4	17B5	Mn
17B6		Mc
17B7	17BD	Mn
17BE	17C5	Mc
17C6		Mn
17C7	17C8	Mc
17C9	17D3	Mn
17D4	17D6	Po
17D7		Lm
17D8	17DA	Po
17DB		Sc
17DC		Lo
17DD		Mn
17E0	17E9	Nd
17F0	17F9	No
1800	1805	Po
1806		Pd
1807	180A	Po
180B	180D	Mn
180E		Cf
180F		Mn
1810	1819	Nd
1820	1842	Lo
1843		Lm
1844	1878	Lo
1880	1884	Lo
1885	1886	Mn
1887	18A8	Lo
18A9		Mn
18AA		Lo
18B0	18F5	Lo
1900	191E	Lo
1920	1922	Mn
1923	1926	Mc
1927	1928	Mn
1929	192B	Mc
1930	1931	Mc
1932		Mn
1933	1938	Mc
1939	193B	Mn
1940		So
1944	1945	Po
1946	194F	Nd
1950	196D	Lo
1970	1974	Lo
1980	19AB	Lo
19B0	19C9	Lo
19D0	19D9	Nd
19DA		No
19DE	19FF	So
1A00	1A16	Lo
1A17	1A18	Mn
1A19	1A1A	Mc
1A1B		Mn
1A1E	1A1F	Po
1A20	1A54	Lo
1A55		Mc
1A56		Mn
1A57		Mc
1A58	1A5E	Mn
1A60		Mn
1A61		Mc
1A62		Mn
1A63	1A64	Mc
1A65	1A6C	Mn
1A6D	1A72	Mc
1A73	1A7C	Mn
1A7F		Mn
1A80	1A89	Nd
1A90	1A99	Nd
1AA0	1AA6	Po
1AA7		Lm
1AA8	1AAD	Po
1AB0	1ABD	Mn
1ABE		Me
1ABF	1ACE	Mn
1B00	1B03	Mn
1B04		Mc
1B05	1B33	Lo
1B34		Mn
1B35		Mc
1B36	1B3A	Mn
1B3B		Mc
1B3C		Mn
1B3D	1B41	Mc
1B42		Mn
1B43	1B44	Mc
1B45	1B4C	Lo
1B50	1B59	Nd
1B5A	1B60	Po
1B61	1B6A	So
1B6B	1B73	Mn
1B74	1B7C	So
1B7D	1B7E	Po
1B80	1B81	Mn
1B82		Mc
1B83	1BA0	Lo
1BA1		Mc
1BA2	1BA5	Mn
1BA6	1BA7	Mc
1BA8	1BA9	Mn
1BAA		Mc
1BAB	1BAD	Mn
1BAE	1BAF	Lo
1BB0	1BB9	Nd
1BBA	1BE5	Lo
1BE6		Mn
1BE7		Mc
1BE8	1BE9	Mn
1BEA	1BEC	Mc
1BED		Mn
1BEE		Mc
1BEF	1BF1	Mn
1BF2	1BF3	Mc
1BFC	1BFF	Po
1C00	1C23	Lo
1C24	1C2B	Mc
1C2C	1C33	Mn
1C34	1C35	Mc
1C36	1C37	Mn
1C3B	1C3F	Po
1C40	1C49	Nd
1C4D	1C4F	Lo
1C50	1C59	Nd
1C5A	1C77	Lo
1C78	1C7D	Lm
1C7E	1C7F	Po
1C80	1C88	Ll
1C90	1CBA	Lu
1CBD	1CBF	Lu
1CC0	1CC7	Po
1CD0	1CD2	Mn
1CD3		Po
1CD4	1CE0	Mn
1CE1		Mc
1CE2	1CE8	Mn
1CE9	1CEC	Lo
1CED		Mn
1CEE	1CF3	Lo
1CF4		Mn
1CF5	1CF6	Lo
1CF7		Mc
1CF8	1CF9	Mn
1CFA		Lo
1D00	1D2B	Ll
1D2C	1D6A	Lm
1D6B	1D77	Ll
1D78		Lm
1D79	1D9A	Ll
1D9B	1DBF	Lm
1DC0	1DFF	Mn
1E00		Lu
1E01		Ll
1E02		Lu
1E03		Ll
1E04		Lu
1E05		Ll
1E06		Lu
1E07		Ll
1E08		Lu
1E09		Ll
1E0A		Lu
1E0B		Ll
1E0C		Lu
1E0D		Ll
1E0E		Lu
1E0F		Ll
1E10		Lu
1E11		Ll
1E12		Lu
1E13		Ll
1E14		Lu
1E15		Ll
1E16		Lu
1E17		Ll
1E18		Lu
1E19		Ll
1E1A		Lu
1E1B		Ll
1E1C		Lu
1E1D		Ll
1E1E		Lu
1E1F		Ll
1E20		Lu
1E21		Ll
1E22		Lu
1E23		Ll
1E24		Lu
1E25		Ll
1E26		Lu
1E27		Ll
1E28		Lu
1E29		Ll
1E2A		Lu
1E2B		Ll
1E2C		Lu
1E2D		Ll
1E2E		Lu
1E2F		Ll
1E30		Lu
1E31		Ll
1E32		Lu
1E33		Ll
1E34		Lu
1E35		Ll
1E36		Lu
1E37		Ll
1E38		Lu
1E39		Ll
1E3A		Lu
1E3B		Ll
1E3C		Lu
1E3D		Ll
1E3E		Lu
1E3F		Ll
1E40		Lu
1E41		Ll
1E42		Lu
1E43		Ll
1E44		Lu
1E45		Ll
1E46		Lu
1E47		Ll
1E48		Lu
1E49		Ll
1E4A		Lu
1E4B		Ll
1E4C		Lu
1E4D		Ll
1E4E		Lu
1E4F		Ll
1E50		Lu
1E51		Ll
1E52		Lu
1E53		Ll
1E54		Lu
1E55		Ll
1E56		Lu
1E57		Ll
1E58		Lu
1E59		Ll
1E5A		Lu
1E5B		Ll
1E5C		Lu
1E5D		Ll
1E5E		Lu
1E5F		Ll
1E60		Lu
1E61		Ll
1E62		Lu
1E63		Ll
1E64		Lu
1E65		Ll
1E66		Lu
1E67		Ll
1E68		Lu
1E69		Ll
1E6A		Lu
1E6B		Ll
1E6C		Lu
1E6D		Ll
1E6E		Lu
1E6F		Ll
1E70		Lu
1E71		Ll
1E72		Lu
1E73		Ll
1E74		Lu
1E75		Ll
1E76		Lu
1E77		Ll
1E78		Lu
1E79		Ll
1E7A		Lu
1E7B		Ll
1E7C		Lu
1E7D		Ll
1E7E		Lu
1E7F		Ll
1E80		Lu
1E81		Ll
1E82		Lu
1E83		Ll
1E84		Lu
1E85		Ll
1E86		Lu
1E87		Ll
1E88		Lu
1E89		Ll
1E8A		Lu
1E8B		Ll
1E8C		Lu
1E8D		Ll
1E8E		Lu
1E8F		Ll
1E90		Lu
1E91		Ll
1E92		Lu
1E93		Ll
1E94		Lu
1E95	1E9D	Ll
1E9E		Lu
1E9F		Ll
1EA0		Lu
1EA1		Ll
1EA2		Lu
1EA3		Ll
1EA4		Lu
1EA5		Ll
1EA6		Lu
1EA7		Ll
1EA8		Lu
1EA9		Ll
1EAA		Lu
1EAB		Ll
1EAC		Lu
1EAD		Ll
1EAE		Lu
1EAF		Ll
1EB0		Lu
1EB1		Ll
1EB2		Lu
1EB3		Ll
1EB4		Lu
1EB5		Ll
1EB6		Lu
1EB7		Ll
1EB8		Lu
1EB9		Ll
1EBA		Lu
1EBB		Ll
1EBC		Lu
1EBD		Ll
1EBE		Lu
1EBF		Ll
1EC0		Lu
1EC1		Ll
1EC2		Lu
1EC3		Ll
1EC4		Lu
1EC5		Ll
1EC6		Lu
1EC7		Ll
1EC8		Lu
1EC9		Ll
1ECA		Lu
1ECB		Ll
1ECC		Lu
1ECD		Ll
1ECE		Lu
1ECF		Ll
1ED0		Lu
1ED1		Ll
1ED2		Lu
1ED3		Ll
1ED4		Lu
1ED5		Ll
1ED6		Lu
1ED7		Ll
1ED8		Lu
1ED9		Ll
1EDA		Lu
1EDB		Ll
1EDC		Lu
1EDD		Ll
1EDE		Lu
1EDF		Ll
1EE0		Lu
1EE1		Ll
1EE2		Lu
1EE3		Ll
1EE4		Lu
1EE5		Ll
1EE6		Lu
1EE7		Ll
1EE8		Lu
1EE9		Ll
1EEA		Lu
1EEB		Ll
1EEC		Lu
1EED		Ll
1EEE		Lu
1EEF		Ll
1EF0		Lu
1EF1		Ll
1EF2		Lu
1EF3		Ll
1EF4		Lu
1EF5		Ll
1EF6		Lu
1EF7		Ll
1EF8		Lu
1EF9		Ll
1EFA		Lu
1EFB		Ll
1EFC		Lu
1EFD		Ll
1EFE		Lu
1EFF	1F07	Ll
1F08	1F0F	Lu
1F10	1F15	Ll
1F18	1F1D	Lu
1F20	1F27	Ll
1F28	1F2F	Lu
1F30	1F37	Ll
1F38	1F3F	Lu
1F40	1F45	Ll
1F48	1F4D	Lu
1F50	1F57	Ll
1F59		Lu
1F5B		Lu
1F5D		Lu
1F5F		Lu
1F60	1F67	Ll
1F68	1F6F	Lu
1F70	1F7D	Ll
1F80	1F87	Ll
1F88	1F8F	Lt
1F90	1F97	Ll
1F98	1F9F	Lt
1FA0	1FA7	Ll
1FA8	1FAF	Lt
1FB0	1FB4	Ll
1FB6	1FB7	Ll
1FB8	1FBB	Lu
1FBC		Lt
1FBD		Sk
1FBE		Ll
1FBF	1FC1	Sk
1FC2	1FC4	Ll
1FC6	1FC7	Ll
1FC8	1FCB	Lu
1FCC		Lt
1FCD	1FCF	Sk
1FD0	1FD3	Ll
1FD6	1FD7	Ll
1FD8	1FDB	Lu
1FDD	1FDF	Sk
1FE0	1FE7	Ll
1FE8	1FEC	Lu
1FED	1FEF	Sk
1FF2	1FF4	Ll
1FF6	1FF7	Ll
1FF8	1FFB	Lu
1FFC		Lt
1FFD	1FFE	Sk
2000	200A	Zs
200B	200F	Cf
2010	2015	Pd
2016	2017	Po
2018		Pi
2019		Pf
201A		Ps
201B	201C	Pi
201D		Pf
201E		Ps
201F		Pi
2020	2027	Po
2028		Zl
2029		Zp
202A	202E	Cf
202F		Zs
2030	2038	Po
2039		Pi
203A		Pf
203B	203E	Po
203F	2040	Pc
2041	2043	Po
2044		Sm
2045		Ps
2046		Pe
2047	2051	Po
2052		Sm
2053		Po
2054		Pc
2055	205E	Po
205F		Zs
2060	2064	Cf
2066	206F	Cf
2070		No
2071		Lm
2074	2079	No
207A	207C	Sm
207D		Ps
207E		Pe
207F		Lm
2080	2089	No
208A	208C	Sm
208D		Ps
208E		Pe
2090	209C	Lm
20A0	20C0	Sc
20D0	20DC	Mn
20DD	20E0	Me
20E1		Mn
20E2	20E4	Me
20E5	20F0	Mn
2100	2101	So
2102		Lu
2103	2106	So
2107		Lu
2108	2109	So
210A		Ll
210B	210D	Lu
210E	210F	Ll
2110	2112	Lu
2113		Ll
2114		So
2115		Lu
2116	2117	So
2118		Sm
2119	211D	Lu
211E	2123	So
2124		Lu
2125		So
2126		Lu
2127		So
2128		Lu
2129		So
212A	212D	Lu
212E		So
212F		Ll
2130	2133	Lu
2134		Ll
2135	2138	Lo
2139		Ll
213A	213B	So
213C	213D	Ll
213E	213F	Lu
2140	2144	Sm
2145		Lu
2146	2149	Ll
214A		So
214B		Sm
214C	214D	So
214E		Ll
214F		So
2150	215F	No
2160	2182	Nl
2183		Lu
2184		Ll
2185	2188	Nl
2189		No
218A	218B	So
2190	2194	Sm
2195	2199	So
219A	219B	Sm
219C	219F	So
21A0		Sm
21A1	21A2	So
21A3		Sm
21A4	21A5	So
21A6		Sm
21A7	21AD	So
21AE		Sm
21AF	21CD	So
21CE	21CF	Sm
21D0	21D1	So
21D2		Sm
21D3		So
21D4		Sm
21D5	21F3	So
21F4	22FF	Sm
2300	2307	So
2308		Ps
2309		Pe
230A		Ps
230B		Pe
230C	231F	So
2320	2321	Sm
2322	2328	So
2329		Ps
232A		Pe
232B	237B	So
237C		Sm
237D	239A	So
239B	23B3	Sm
23B4	23DB	So
23DC	23E1	Sm
23E2	2426	So
2440	244A	So
2460	249B	No
249C	24E9	So
24EA	24FF	No
2500	25B6	So
25B7		Sm
25B8	25C0	So
25C1		Sm
25C2	25F7	So
25F8	25FF	Sm
2600	266E	So
266F		Sm
2670	2767	So
2768		Ps
2769		Pe
276A		Ps
276B		Pe
276C		Ps
276D		Pe
276E		Ps
276F		Pe
2770		Ps
2771		Pe
2772		Ps
2773		Pe
2774		Ps
2775		Pe
2776	2793	No
2794	27BF	So
27C0	27C4	Sm
27C5		Ps
27C6		Pe
27C7	27E5	Sm
27E6		Ps
27E7		Pe
27E8		Ps
27E9		Pe
27EA		Ps
27EB		Pe
27EC		Ps
27ED		Pe
27EE		Ps
27EF		Pe
27F0	27FF	Sm
2800	28FF	So
2900	2982	Sm
2983		Ps
2984		Pe
2985		Ps
2986		Pe
2987		Ps
2988		Pe
2989		Ps
298A		Pe
298B		Ps
298C		Pe
298D		Ps
298E		Pe
298F		Ps
2990		Pe
2991		Ps
2992		Pe
2993		Ps
2994		Pe
2995		Ps
2996		Pe
2997		Ps
2998		Pe
2999	29D7	Sm
29D8		Ps
29D9		Pe
29DA		Ps
29DB		Pe
29DC	29FB	Sm
29FC		Ps
29FD		Pe
29FE	2AFF	Sm
2B00	2B2F	So
2B30	2B44	Sm
2B45	2B46	So
2B47	2B4C	Sm
2B4D	2B73	So
2B76	2B95	So
2B97	2BFF	So
2C00	2C2F	Lu
2C30	2C5F	Ll
2C60		Lu
2C61		Ll
2C62	2C64	Lu
2C65	2C66	Ll
2C67		Lu
2C68		Ll
2C69		Lu
2C6A		Ll
2C6B		Lu
2C6C		Ll
2C6D	2C70	Lu
2C71		Ll
2C72		Lu
2C73	2C74	Ll
2C75		Lu
2C76	2C7B	Ll
2C7C	2C7D	Lm
2C7E	2C80	Lu
2C81		Ll
2C82		Lu
2C83		Ll
2C84		Lu
2C85		Ll
2C86		Lu
2C87		Ll
2C88		Lu
2C89		Ll
2C8A		Lu
2C8B		Ll
2C8C		Lu
2C8D		Ll
2C8E		Lu
2C8F		Ll
2C90		Lu
2C91		Ll
2C92		Lu
2C93		Ll
2C94		Lu
2C95		Ll
2C96		Lu
2C97		Ll
2C98		Lu
2C99		Ll
2C9A		Lu
2C9B		Ll
2C9C		Lu
2C9D		Ll
2C9E		Lu
2C9F		Ll
2CA0		Lu
2CA1		Ll
2CA2		Lu
2CA3		Ll
2CA4		Lu
2CA5		Ll
2CA6		Lu
2CA7		Ll
2CA8		Lu
2CA9		Ll
2CAA		Lu
2CAB		Ll
2CAC		Lu
2CAD		Ll
2CAE		Lu
2CAF		Ll
2CB0		Lu
2CB1		Ll
2CB2		Lu
2CB3		Ll
2CB4		Lu
2CB5		Ll
2CB6		Lu
2CB7		Ll
2CB8		Lu
2CB9		Ll
2CBA		Lu
2CBB		Ll
2CBC		Lu
2CBD		Ll
2CBE		Lu
2CBF		Ll
2CC0		Lu
2CC1		Ll
2CC2		Lu
2CC3		Ll
2CC4		Lu
2CC5		Ll
2CC6		Lu
2CC7		Ll
2CC8		Lu
2CC9		Ll
2CCA		Lu
2CCB		Ll
2CCC		Lu
2CCD		Ll
2CCE		Lu
2CCF		Ll
2CD0		Lu
2CD1		Ll
2CD2		Lu
2CD3		Ll
2CD4		Lu
2CD5		Ll
2CD6		Lu
2CD7		Ll
2CD8		Lu
2CD9		Ll
2CDA		Lu
2CDB		Ll
2CDC		Lu
2CDD		Ll
2CDE		Lu
2CDF		Ll
2CE0		Lu
2CE1		Ll
2CE2		Lu
2CE3	2CE4	Ll
2CE5	2CEA	So
2CEB		Lu
2CEC		Ll
2CED		Lu
2CEE		Ll
2CEF	2CF1	Mn
2CF2		Lu
2CF3		Ll
2CF9	2CFC	Po
2CFD		No
2CFE	2CFF	Po
2D00	2D25	Ll
2D27		Ll
2D2D		Ll
2D30	2D67	Lo
2D6F		Lm
2D70		Po
2D7F		Mn
2D80	2D96	Lo
2DA0	2DA6	Lo
2DA8	2DAE	Lo
2DB0	2DB6	Lo
2DB8	2DBE	Lo
2DC0	2DC6	Lo
2DC8	2DCE	Lo
2DD0	2DD6	Lo
2DD8	2DDE	Lo
2DE0	2DFF	Mn
2E00	2E01	Po
2E02		Pi
2E03		Pf
2E04		Pi
2E05		Pf
2E06	2E08	Po
2E09		Pi
2E0A		Pf
2E0B		Po
2E0C		Pi
2E0D		Pf
2E0E	2E16	Po
2E17		Pd
2E18	2E19	Po
2E1A		Pd
2E1B		Po
2E1C		Pi
2E1D		Pf
2E1E	2E1F	Po
2E20		Pi
2E21		Pf
2E22		Ps
2E23		Pe
2E24		Ps
2E25		Pe
2E26		Ps
2E27		Pe
2E28		Ps
2E29		Pe
2E2A	2E2E	Po
2E2F		Lm
2E30	2E39	Po
2E3A	2E3B	Pd
2E3C	2E3F	Po
2E40		Pd
2E41		Po
2E42		Ps
2E43	2E4F	Po
2E50	2E51	So
2E52	2E54	Po
2E55		Ps
2E56		Pe
2E57		Ps
2E58		Pe
2E59		Ps
2E5A		Pe
2E5B		Ps
2E5C		Pe
2E5D		Pd
2E80	2E99	So
2E9B	2EF3	So
2F00	2FD5	So
2FF0	2FFB	So
3000		Zs
3001	3003	Po
3004		So
3005		Lm
3006		Lo
3007		Nl
3008		Ps
3009		Pe
300A		Ps
300B		Pe
300C		Ps
300D		Pe
300E		Ps
300F		Pe
3010		Ps
3011		Pe
3012	3013	So
3014		Ps
3015		Pe
3016		Ps
3017		Pe
3018		Ps
3019		Pe
301A		Ps
301B		Pe
301C		Pd
301D		Ps
301E	301F	Pe
3020		So
3021	3029	Nl
302A	302D	Mn
302E	302F	Mc
3030		Pd
3031	3035	Lm
3036	3037	So
3038	303A	Nl
303B		Lm
303C		Lo
303D		Po
303E	303F	So
3041	3096	Lo
3099	309A	Mn
309B	309C	Sk
309D	309E	Lm
309F		Lo
30A0		Pd
30A1	30FA	Lo
30FB		Po
30FC	30FE	Lm
30FF		Lo
3105	312F	Lo
3131	318E	Lo
3190	3191	So
3192	3195	No
3196	319F	So
31A0	31BF	Lo
31C0	31E3	So
31F0	31FF	Lo
3200	321E	So
3220	3229	No
322A	3247	So
3248	324F	No
3250		So
3251	325F	No
3260	327F	So
3280	3289	No
328A	32B0	So
32B1	32BF	No
32C0	33FF	So
3400	4DBF	Lo
4DC0	4DFF	So
4E00	A014	Lo
A015		Lm
A016	A48C	Lo
A490	A4C6	So
A4D0	A4F7	Lo
A4F8	A4FD	Lm
A4FE	A4FF	Po
A500	A60B	Lo
A60C		Lm
A60D	A60F	Po
A610	A61F	Lo
A620	A629	Nd
A62A	A62B	Lo
A640		Lu
A641		Ll
A642		Lu
A643		Ll
A644		Lu
A645		Ll
A646		Lu
A647		Ll
A648		Lu
A649		Ll
A64A		Lu
A64B		Ll
A64C		Lu
A64D		Ll
A64E		Lu
A64F		Ll
A650		Lu
A651		Ll
A652		Lu
A653		Ll
A654		Lu
A655		Ll
A656		Lu
A657		Ll
A658		Lu
A659		Ll
A65A		Lu
A65B		Ll
A65C		Lu
A65D		Ll
A65E		Lu
A65F		Ll
A660		Lu
A661		Ll
A662		Lu
A663		Ll
A664		Lu
A665		Ll
A666		Lu
A667		Ll
A668		Lu
A669		Ll
A66A		Lu
A66B		Ll
A66C		Lu
A66D		Ll
A66E		Lo
A66F		Mn
A670	A672	Me
A673		Po
A674	A67D	Mn
A67E		Po
A67F		Lm
A680		Lu
A681		Ll
A682		Lu
A683		Ll
A684		Lu
A685		Ll
A686		Lu
A687		Ll
A688		Lu
A689		Ll
A68A		Lu
A68B		Ll
A68C		Lu
A68D		Ll
A68E		Lu
A68F		Ll
A690		Lu
A691		Ll
A692		Lu
A693		Ll
A694		Lu
A695		Ll
A696		Lu
A697		Ll
A698		Lu
A699		Ll
A69A		Lu
A69B		Ll
A69C	A69D	Lm
A69E	A69F	Mn
A6A0	A6E5	Lo
A6E6	A6EF	Nl
A6F0	A6F1	Mn
A6F2	A6F7	Po
A700	A716	Sk
A717	A71F	Lm
A720	A721	Sk
A722		Lu
A723		Ll
A724		Lu
A725		Ll
A726		Lu
A727		Ll
A728		Lu
A729		Ll
A72A		Lu
A72B		Ll
A72C		Lu
A72D		Ll
A72E		Lu
A72F	A731	Ll
A732		Lu
A733		Ll
A734		Lu
A735		Ll
A736		Lu
A737		Ll
A738		Lu
A739		Ll
A73A		Lu
A73B		Ll
A73C		Lu
A73D		Ll
A73E		Lu
A73F		Ll
A740		Lu
A741		Ll
A742		Lu
A743		Ll
A744		Lu
A745		Ll
A746		Lu
A747		Ll
A748		Lu
A749		Ll
A74A		Lu
A74B		Ll
A74C		Lu
A74D		Ll
A74E		Lu
A74F		Ll
A750		Lu
A751		Ll
A752		Lu
A753		Ll
A754		Lu
A755		Ll
A756		Lu
A757		Ll
A758		Lu
A759		Ll
A75A		Lu
A75B		Ll
A75C		Lu
A75D		Ll
A75E		Lu
A75F		Ll
A760		Lu
A761		Ll
A762		Lu
A763		Ll
A764		Lu
A765		Ll
A766		Lu
A767		Ll
A768		Lu
A769		Ll
A76A		Lu
A76B		Ll
A76C		Lu
A76D		Ll
A76E		Lu
A76F		Ll
A770		Lm
A771	A778	Ll
A779		Lu
A77A		Ll
A77B		Lu
A77C		Ll
A77D	A77E	Lu
A77F		Ll
A780		Lu
A781		Ll
A782		Lu
A783		Ll
A784		Lu
A785		Ll
A786		Lu
A787		Ll
A788		Lm
A789	A78A	Sk
A78B		Lu
A78C		Ll
A78D		Lu
A78E		Ll
A78F		Lo
A790		Lu
A791		Ll
A792		Lu
A793	A795	Ll
A796		Lu
A797		Ll
A798		Lu
A799		Ll
A79A		Lu
A79B		Ll
A79C		Lu
A79D		Ll
A79E		Lu
A79F		Ll
A7A0		Lu
A7A1		Ll
A7A2		Lu
A7A3		Ll
A7A4		Lu
A7A5		Ll
A7A6		Lu
A7A7		Ll
A7A8		Lu
A7A9		Ll
A7AA	A7AE	Lu
A7AF		Ll
A7B0	A7B4	Lu
A7B5		Ll
A7B6		Lu
A7B7		Ll
A7B8		Lu
A7B9		Ll
A7BA		Lu
A7BB		Ll
A7BC		Lu
A7BD		Ll
A7BE		Lu
A7BF		Ll
A7C0		Lu
A7C1		Ll
A7C2		Lu
A7C3		Ll
A7C4	A7C7	Lu
A7C8		Ll
A7C9		Lu
A7CA		Ll
A7D0		Lu
A7D1		Ll
A7D3		Ll
A7D5		Ll
A7D6		Lu
A7D7		Ll
A7D8		Lu
A7D9		Ll
A7F2	A7F4	Lm
A7F5		Lu
A7F6		Ll
A7F7		Lo
A7F8	A7F9	Lm
A7FA		Ll
A7FB	A801	Lo
A802		Mn
A803	A805	Lo
A806		Mn
A807	A80A	Lo
A80B		Mn
A80C	A822	Lo
A823	A824	Mc
A825	A826	Mn
A827		Mc
A828	A82B	So
A82C		Mn
A830	A835	No
A836	A837	So
A838		Sc
A839		So
A840	A873	Lo
A874	A877	Po
A880	A881	Mc
A882	A8B3	Lo
A8B4	A8C3	Mc
A8C4	A8C5	Mn
A8CE	A8CF	Po
A8D0	A8D9	Nd
A8E0	A8F1	Mn
A8F2	A8F7	Lo
A8F8	A8FA	Po
A8FB		Lo
A8FC		Po
A8FD	A8FE	Lo
A8FF		Mn
A900	A909	Nd
A90A	A925	Lo
A926	A92D	Mn
A92E	A92F	Po
A930	A946	Lo
A947	A951	Mn
A952	A953	Mc
A95F		Po
A960	A97C	Lo
A980	A982	Mn
A983		Mc
A984	A9B2	Lo
A9B3		Mn
A9B4	A9B5	Mc
A9B6	A9B9	Mn
A9BA	A9BB	Mc
A9BC	A9BD	Mn
A9BE	A9C0	Mc
A9C1	A9CD	Po
A9CF		Lm
A9D0	A9D9	Nd
A9DE	A9DF	Po
A9E0	A9E4	Lo
A9E5		Mn
A9E6		Lm
A9E7	A9EF	Lo
A9F0	A9F9	Nd
A9FA	A9FE	Lo
AA00	AA28	Lo
AA29	AA2E	Mn
AA2F	AA30	Mc
AA31	AA32	Mn
AA33	AA34	Mc
AA35	AA36	Mn
AA40	AA42	Lo
AA43		Mn
AA44	AA4B	Lo
AA4C		Mn
AA4D		Mc
AA50	AA59	Nd
AA5C	AA5F	Po
AA60	AA6F	Lo
AA70		Lm
AA71	AA76	Lo
AA77	AA79	So
AA7A		Lo
AA7B		Mc
AA7C		Mn
AA7D		Mc
AA7E	AAAF	Lo
AAB0		Mn
AAB1		Lo
AAB2	AAB4	Mn
AAB5	AAB6	Lo
AAB7	AAB8	Mn
AAB9	AABD	Lo
AABE	AABF	Mn
AAC0		Lo
AAC1		Mn
AAC2		Lo
AADB	AADC	Lo
AADD		Lm
AADE	AADF	Po
AAE0	AAEA	Lo
AAEB		Mc
AAEC	AAED	Mn
AAEE	AAEF	Mc
AAF0	AAF1	Po
AAF2		Lo
AAF3	AAF4	Lm
AAF5		Mc
AAF6		Mn
AB01	AB06	Lo
AB09	AB0E	Lo
AB11	AB16	Lo
AB20	AB26	Lo
AB28	AB2E	Lo
AB30	AB5A	Ll
AB5B		Sk
AB5C	AB5F	Lm
AB60	AB68	Ll
AB69		Lm
AB6A	AB6B	Sk
AB70	ABBF	Ll
ABC0	ABE2	Lo
ABE3	ABE4	Mc
ABE5		Mn
ABE6	ABE7	Mc
ABE8		Mn
ABE9	ABEA	Mc
ABEB		Po
ABEC		Mc
ABED		Mn
ABF0	ABF9	Nd
AC00	D7A3	Lo
D7B0	D7C6	Lo
D7CB	D7FB	Lo
D800	DFFF	Cs
E000	F8FF	Co
F900	FA6D	Lo
FA70	FAD9	Lo
FB00	FB06	Ll
FB13	FB17	Ll
FB1D		Lo
FB1E		Mn
FB1F	FB28	Lo
FB29		Sm
FB2A	FB36	Lo
FB38	FB3C	Lo
FB3E		Lo
FB40	FB41	Lo
FB43	FB44	Lo
FB46	FBB1	Lo
FBB2	FBC2	Sk
FBD3	FD3D	Lo
FD3E		Pe
FD3F		Ps
FD40	FD4F	So
FD50	FD8F	Lo
FD92	FDC7	Lo
FDCF		So
FDF0	FDFB	Lo
FDFC		Sc
FDFD	FDFF	So
FE00	FE0F	Mn
FE10	FE16	Po
FE17		Ps
FE18		Pe
FE19		Po
FE20	FE2F	Mn
FE30		Po
FE31	FE32	Pd
FE33	FE34	Pc
FE35		Ps
FE36		Pe
FE37		Ps
FE38		Pe
FE39		Ps
FE3A		Pe
FE3B		Ps
FE3C		Pe
FE3D		Ps
FE3E		Pe
FE3F		Ps
FE40		Pe
FE41		Ps
FE42		Pe
FE43		Ps
FE44		Pe
FE45	FE46	Po
FE47		Ps
FE48		Pe
FE49	FE4C	Po
FE4D	FE4F	Pc
FE50	FE52	Po
FE54	FE57	Po
FE58		Pd
FE59		Ps
FE5A		Pe
FE5B		Ps
FE5C		Pe
FE5D		Ps
FE5E		Pe
FE5F	FE61	Po
FE62		Sm
FE63		Pd
FE64	FE66	Sm
FE68		Po
FE69		Sc
FE6A	FE6B	Po
FE70	FE74	Lo
FE76	FEFC	Lo
FEFF		Cf
FF01	FF03	Po
FF04		Sc
FF05	FF07	Po
FF08		Ps
FF09		Pe
FF0A		Po
FF0B		Sm
FF0C		Po
FF0D		Pd
FF0E	FF0F	Po
FF10	FF19	Nd
FF1A	FF1B	Po
FF1C	FF1E	Sm
FF1F	FF20	Po
FF21	FF3A	Lu
FF3B		Ps
FF3C		Po
FF3D		Pe
FF3E		Sk
FF3F		Pc
FF40		Sk
FF41	FF5A	Ll
FF5B		Ps
FF5C		Sm
FF5D		Pe
FF5E		Sm
FF5F		Ps
FF60		Pe
FF61		Po
FF62		Ps
FF63		Pe
FF64	FF65	Po
FF66	FF6F	Lo
FF70		Lm
FF71	FF9D	Lo
FF9E	FF9F	Lm
FFA0	FFBE	Lo
FFC2	FFC7	Lo
FFCA	FFCF	Lo
FFD2	FFD7	Lo
FFDA	FFDC	Lo
FFE0	FFE1	Sc
FFE2		Sm
FFE3		Sk
FFE4		So
FFE5	FFE6	Sc
FFE8		So
FFE9	FFEC	Sm
FFED	FFEE	So
FFF9	FFFB	Cf
FFFC	FFFD	So
10000	1000B	Lo
1000D	10026	Lo
10028	1003A	Lo
1003C	1003D	Lo
1003F	1004D	Lo
10050	1005D	Lo
10080	100FA	Lo
10100	10102	Po
10107	10133	No
10137	1013F	So
10140	10174	Nl
10175	10178	No
10179	10189	So
1018A	1018B	No
1018C	1018E	So
10190	1019C	So
101A0		So
101D0	101FC	So
101FD		Mn
10280	1029C	Lo
102A0	102D0	Lo
102E0		Mn
102E1	102FB	No
10300	1031F	Lo
10320	10323	No
1032D	10340	Lo
10341		Nl
10342	10349	Lo
1034A		Nl
10350	10375	Lo
10376	1037A	Mn
10380	1039D	Lo
1039F		Po
103A0	103C3	Lo
103C8	103CF	Lo
103D0		Po
103D1	103D5	Nl
10400	10427	Lu
10428	1044F	Ll
10450	1049D	Lo
104A0	104A9	Nd
104B0	104D3	Lu
104D8	104FB	Ll
10500	10527	Lo
10530	10563	Lo
1056F		Po
10570	1057A	Lu
1057C	1058A	Lu
1058C	10592	Lu
10594	10595	Lu
10597	105A1	Ll
105A3	105B1	Ll
105B3	105B9	Ll
105BB	105BC	Ll
10600	10736	Lo
10740	10755	Lo
10760	10767	Lo
10780	10785	Lm
10787	107B0	Lm
107B2	107BA	Lm
10800	10805	Lo
10808		Lo
1080A	10835	Lo
10837	10838	Lo
1083C		Lo
1083F	10855	Lo
10857		Po
10858	1085F	No
10860	10876	Lo
10877	10878	So
10879	1087F	No
10880	1089E	Lo
108A7	108AF	No
108E0	108F2	Lo
108F4	108F5	Lo
108FB	108FF	No
10900	10915	Lo
10916	1091B	No
1091F		Po
10920	10939	Lo
1093F		Po
10980	109B7	Lo
109BC	109BD	No
109BE	109BF	Lo
109C0	109CF	No
109D2	109FF	No
10A00		Lo
10A01	10A03	Mn
10A05	10A06	Mn
10A0C	10A0F	Mn
10A10	10A13	Lo
10A15	10A17	Lo
10A19	10A35	Lo
10A38	10A3A	Mn
10A3F		Mn
10A40	10A48	No
10A50	10A58	Po
10A60	10A7C	Lo
10A7D	10A7E	No
10A7F		Po
10A80	10A9C	Lo
10A9D	10A9F	No
10AC0	10AC7	Lo
10AC8		So
10AC9	10AE4	Lo
10AE5	10AE6	Mn
10AEB	10AEF	No
10AF0	10AF6	Po
10B00	10B35	Lo
10B39	10B3F	Po
10B40	10B55	Lo
10B58	10B5F	No
10B60	10B72	Lo
10B78	10B7F	No
10B80	10B91	Lo
10B99	10B9C	Po
10BA9	10BAF	No
10C00	10C48	Lo
10C80	10CB2	Lu
10CC0	10CF2	Ll
10CFA	10CFF	No
10D00	10D23	Lo
10D24	10D27	Mn
10D30	10D39	Nd
10E60	10E7E	No
10E80	10EA9	Lo
10EAB	10EAC	Mn
10EAD		Pd
10EB0	10EB1	Lo
10EFD	10EFF	Mn
10F00	10F1C	Lo
10F1D	10F26	No
10F27		Lo
10F30	10F45	Lo
10F46	10F50	Mn
10F51	10F54	No
10F55	10F59	Po
10F70	10F81	Lo
10F82	10F85	Mn
10F86	10F89	Po
10FB0	10FC4	Lo
10FC5	10FCB	No
10FE0	10FF6	Lo
11000		Mc
11001		Mn
11002		Mc
11003	11037	Lo
11038	11046	Mn
11047	1104D	Po
11052	11065	No
11066	1106F	Nd
11070		Mn
11071	11072	Lo
11073	11074	Mn
11075		Lo
1107F	11081	Mn
11082		Mc
11083	110AF	Lo
110B0	110B2	Mc
110B3	110B6	Mn
110B7	110B8	Mc
110B9	110BA	Mn
110BB	110BC	Po
110BD		Cf
110BE	110C1	Po
110C2		Mn
110CD		Cf
110D0	110E8	Lo
110F0	110F9	Nd
11100	11102	Mn
11103	11126	Lo
11127	1112B	Mn
1112C		Mc
1112D	11134	Mn
11136	1113F	Nd
11140	11143	Po
11144		Lo
11145	11146	Mc
11147		Lo
11150	11172	Lo
11173		Mn
11174	11175	Po
11176		Lo
11180	11181	Mn
11182		Mc
11183	111B2	Lo
111B3	111B5	Mc
111B6	111BE	Mn
111BF	111C0	Mc
111C1	111C4	Lo
111C5	111C8	Po
111C9	111CC	Mn
111CD		Po
111CE		Mc
111CF		Mn
111D0	111D9	Nd
111DA		Lo
111DB		Po
111DC		Lo
111DD	111DF	Po
111E1	111F4	No
11200	11211	Lo
11213	1122B	Lo
1122C	1122E	Mc
1122F	11231	Mn
11232	11233	Mc
11234		Mn
11235		Mc
11236	11237	Mn
11238	1123D	Po
1123E		Mn
1123F	11240	Lo
11241		Mn
11280	11286	Lo
11288		Lo
1128A	1128D	Lo
1128F	1129D	Lo
1129F	112A8	Lo
112A9		Po
112B0	112DE	Lo
112DF		Mn
112E0	112E2	Mc
112E3	112EA	Mn
112F0	112F9	Nd
11300	11301	Mn
11302	11303	Mc
11305	1130C	Lo
1130F	11310	Lo
11313	11328	Lo
1132A	11330	Lo
11332	11333	Lo
11335	11339	Lo
1133B	1133C	Mn
1133D		Lo
1133E	1133F	Mc
11340		Mn
11341	11344	Mc
11347	11348	Mc
1134B	1134D	Mc
11350		Lo
11357		Mc
1135D	11361	Lo
11362	11363	Mc
11366	1136C	Mn
11370	11374	Mn
11400	11434	Lo
11435	11437	Mc
11438	1143F	Mn
11440	11441	Mc
11442	11444	Mn
11445		Mc
11446		Mn
11447	1144A	Lo
1144B	1144F	Po
11450	11459	Nd
1145A	1145B	Po
1145D		Po
1145E		Mn
1145F	11461	Lo
11480	114AF	Lo
114B0	114B2	Mc
114B3	114B8	Mn
114B9		Mc
114BA		Mn
114BB	114BE	Mc
114BF	114C0	Mn
114C1		Mc
114C2	114C3	Mn
114C4	114C5	Lo
114C6		Po
114C7		Lo
114D0	114D9	Nd
11580	115AE	Lo
115AF	115B1	Mc
115B2	115B5	Mn
115B8	115BB	Mc
115BC	115BD	Mn
115BE		Mc
115BF	115C0	Mn
115C1	115D7	Po
115D8	115DB	Lo
115DC	115DD	Mn
11600	1162F	Lo
11630	11632	Mc
11633	1163A	Mn
1163B	1163C	Mc
1163D		Mn
1163E		Mc
1163F	11640	Mn
11641	11643	Po
11644		Lo
11650	11659	Nd
11660	1166C	Po
11680	116AA	Lo
116AB		Mn
116AC		Mc
116AD		Mn
116AE	116AF	Mc
116B0	116B5	Mn
116B6		Mc
116B7		Mn
116B8		Lo
116B9		Po
116C0	116C9	Nd
11700	1171A	Lo
1171D	1171F	Mn
11720	11721	Mc
11722	11725	Mn
11726		Mc
11727	1172B	Mn
11730	11739	Nd
1173A	1173B	No
1173C	1173E	Po
1173F		So
11740	11746	Lo
11800	1182B	Lo
1182C	1182E	Mc
1182F	11837	Mn
11838		Mc
11839	1183A	Mn
1183B		Po
118A0	118BF	Lu
118C0	118DF	Ll
118E0	118E9	Nd
118EA	118F2	No
118FF	11906	Lo
11909		Lo
1190C	11913	Lo
11915	11916	Lo
11918	1192F	Lo
11930	11935	Mc
11937	11938	Mc
1193B	1193C	Mn
1193D		Mc
1193E		Mn
1193F		Lo
11940		Mc
11941		Lo
11942		Mc
11943		Mn
11944	11946	Po
11950	11959	Nd
119A0	119A7	Lo
119AA	119D0	Lo
119D1	119D3	Mc
119D4	119D7	Mn
119DA	119DB	Mn
119DC	119DF	Mc
119E0		Mn
119E1		Lo
119E2		Po
119E3		Lo
119E4		Mc
11A00		Lo
11A01	11A0A	Mn
11A0B	11A32	Lo
11A33	11A38	Mn
11A39		Mc
11A3A		Lo
11A3B	11A3E	Mn
11A3F	11A46	Po
11A47		Mn
11A50		Lo
11A51	11A56	Mn
11A57	11A58	Mc
11A59	11A5B	Mn
11A5C	11A89	Lo
11A8A	11A96	Mn
11A97		Mc
11A98	11A99	Mn
11A9A	11A9C	Po
11A9D		Lo
11A9E	11AA2	Po
11AB0	11AF8	Lo
11B00	11B09	Po
11C00	11C08	Lo
11C0A	11C2E	Lo
11C2F		Mc
11C30	11C36	Mn
11C38	11C3D	Mn
11C3E		Mc
11C3F		Mn
11C40		Lo
11C41	11C45	Po
11C50	11C59	Nd
11C5A	11C6C	No
11C70	11C71	Po
11C72	11C8F	Lo
11C92	11CA7	Mn
11CA9		Mc
11CAA	11CB0	Mn
11CB1		Mc
11CB2	11CB3	Mn
11CB4		Mc
11CB5	11CB6	Mn
11D00	11D06	Lo
11D08	11D09	Lo
11D0B	11D30	Lo
11D31	11D36	Mn
11D3A		Mn
11D3C	11D3D	Mn
11D3F	11D45	Mn
11D46		Lo
11D47		Mn
11D50	11D59	Nd
11D60	11D65	Lo
11D67	11D68	Lo
11D6A	11D89	Lo
11D8A	11D8E	Mc
11D90	11D91	Mn
11D93	11D94	Mc
11D95		Mn
11D96		Mc
11D97		Mn
11D98		Lo
11DA0	11DA9	Nd
11EE0	11EF2	Lo
11EF3	11EF4	Mn
11EF5	11EF6	Mc
11EF7	11EF8	Po
11F00	11F01	Mn
11F02		Lo
11F03		Mc
11F04	11F10	Lo
11F12	11F33	Lo
11F34	11F35	Mc
11F36	11F3A	Mn
11F3E	11F3F	Mc
11F40		Mn
11F41		Mc
11F42		Mn
11F43	11F4F	Po
11F50	11F59	Nd
11FB0		Lo
11FC0	11FD4	No
11FD5	11FDC	So
11FDD	11FE0	Sc
11FE1	11FF1	So
11FFF		Po
12000	12399	Lo
12400	1246E	Nl
12470	12474	Po
12480	12543	Lo
12F90	12FF0	Lo
12FF1	12FF2	Po
13000	1342F	Lo
13430	1343F	Cf
13440		Mn
13441	13446	Lo
13447	13455	Mn
14400	14646	Lo
16800	16A38	Lo
16A40	16A5E	Lo
16A60	16A69	Nd
16A6E	16A6F	Po
16A70	16ABE	Lo
16AC0	16AC9	Nd
16AD0	16AED	Lo
16AF0	16AF4	Mn
16AF5		Po
16B00	16B2F	Lo
16B30	16B36	Mn
16B37	16B3B	Po
16B3C	16B3F	So
16B40	16B43	Lm
16B44		Po
16B45		So
16B50	16B59	Nd
16B5B	16B61	No
16B63	16B77	Lo
16B7D	16B8F	Lo
16E40	16E5F	Lu
16E60	16E7F	Ll
16E80	16E96	No
16E97	16E9A	Po
16F00	16F4A	Lo
16F4F		Mn
16F50		Lo
16F51	16F87	Mc
16F8F	16F92	Mn
16F93	16F9F	Lm
16FE0	16FE1	Lm
16FE2		Po
16FE3		Lm
16FE4		Mn
16FF0	16FF1	Mc
17000	187F7	Lo
18800	18CD5	Lo
18D00	18D08	Lo
1AFF0	1AFF3	Lm
1AFF5	1AFFB	Lm
1AFFD	1AFFE	Lm
1B000	1B122	Lo
1B132		Lo
1B150	1B152	Lo
1B155		Lo
1B164	1B167	Lo
1B170	1B2FB	Lo
1BC00	1BC6A	Lo
1BC70	1BC7C	Lo
1BC80	1BC88	Lo
1BC90	1BC99	Lo
1BC9C		So
1BC9D	1BC9E	Mn
1BC9F		Po
1BCA0	1BCA3	Cf
1CF00	1CF2D	Mn
1CF30	1CF46	Mn
1CF50	1CFC3	So
1D000	1D0F5	So
1D100	1D126	So
1D129	1D164	So
1D165	1D166	Mc
1D167	1D169	Mn
1D16A	1D16C	So
1D16D	1D172	Mc
1D173	1D17A	Cf
1D17B	1D182	Mn
1D183	1D184	So
1D185	1D18B	Mn
1D18C	1D1A9	So
1D1AA	1D1AD	Mn
1D1AE	1D1EA	So
1D200	1D241	So
1D242	1D244	Mn
1D245		So
1D2C0	1D2D3	No
1D2E0	1D2F3	No
1D300	1D356	So
1D360	1D378	No
1D400	1D419	Lu
1D41A	1D433	Ll
1D434	1D44D	Lu
1D44E	1D454	Ll
1D456	1D467	Ll
1D468	1D481	Lu
1D482	1D49B	Ll
1D49C		Lu
1D49E	1D49F	Lu
1D4A2		Lu
1D4A5	1D4A6	Lu
1D4A9	1D4AC	Lu
1D4AE	1D4B5	Lu
1D4B6	1D4B9	Ll
1D4BB		Ll
1D4BD	1D4C3	Ll
1D4C5	1D4CF	Ll
1D4D0	1D4E9	Lu
1D4EA	1D503	Ll
1D504	1D505	Lu
1D507	1D50A	Lu
1D50D	1D514	Lu
1D516	1D51C	Lu
1D51E	1D537	Ll
1D538	1D539	Lu
1D53B	1D53E	Lu
1D540	1D544	Lu
1D546		Lu
1D54A	1D550	Lu
1D552	1D56B	Ll
1D56C	1D585	Lu
1D586	1D59F	Ll
1D5A0	1D5B9	Lu
1D5BA	1D5D3	Ll
1D5D4	1D5ED	Lu
1D5EE	1D607	Ll
1D608	1D621	Lu
1D622	1D63B	Ll
1D63C	1D655	Lu
1D656	1D66F	Ll
1D670	1D689	Lu
1D68A	1D6A5	Ll
1D6A8	1D6C0	Lu
1D6C1		Sm
1D6C2	1D6DA	Ll
1D6DB		Sm
1D6DC	1D6E1	Ll
1D6E2	1D6FA	Lu
1D6FB		Sm
1D6FC	1D714	Ll
1D715		Sm
1D716	1D71B	Ll
1D71C	1D734	Lu
1D735		Sm
1D736	1D74E	Ll
1D74F		Sm
1D750	1D755	Ll
1D756	1D76E	Lu
1D76F		Sm
1D770	1D788	Ll
1D789		Sm
1D78A	1D78F	Ll
1D790	1D7A8	Lu
1D7A9		Sm
1D7AA	1D7C2	Ll
1D7C3		Sm
1D7C4	1D7C9	Ll
1D7CA		Lu
1D7CB		Ll
1D7CE	1D7FF	Nd
1D800	1D9FF	So
1DA00	1DA36	Mn
1DA37	1DA3A	So
1DA3B	1DA6C	Mn
1DA6D	1DA74	So
1DA75		Mn
1DA76	1DA83	So
1DA84		Mn
1DA85	1DA86	So
1DA87	1DA8B	Po
1DA9B	1DA9F	Mn
1DAA1	1DAAF	Mn
1DF00	1DF09	Ll
1DF0A		Lo
1DF0B	1DF1E	Ll
1DF25	1DF2A	Ll
1E000	1E006	Mn
1E008	1E018	Mn
1E01B	1E021	Mn
1E023	1E024	Mn
1E026	1E02A	Mn
1E030	1E06D	Lm
1E08F		Mn
1E100	1E12C	Lo
1E130	1E136	Mn
1E137	1E13D	Lm
1E140	1E149	Nd
1E14E		Lo
1E14F		So
1E290	1E2AD	Lo
1E2AE		Mn
1E2C0	1E2EB	Lo
1E2EC	1E2EF	Mn
1E2F0	1E2F9	Nd
1E2FF		Sc
1E4D0	1E4EA	Lo
1E4EB		Lm
1E4EC	1E4EF	Mn
1E4F0	1E4F9	Nd
1E7E0	1E7E6	Lo
1E7E8	1E7EB	Lo
1E7ED	1E7EE	Lo
1E7F0	1E7FE	Lo
1E800	1E8C4	Lo
1E8C7	1E8CF	No
1E8D0	1E8D6	Mn
1E900	1E921	Lu
1E922	1E943	Ll
1E944	1E94A	Mn
1E94B		Lm
1E950	1E959	Nd
1E95E	1E95F	Po
1EC71	1ECAB	No
1ECAC		So
1ECAD	1ECAF	No
1ECB0		Sc
1ECB1	1ECB4	No
1ED01	1ED2D	No
1ED2E		So
1ED2F	1ED3D	No
1EE00	1EE03	Lo
1EE05	1EE1F	Lo
1EE21	1EE22	Lo
1EE24		Lo
1EE27		Lo
1EE29	1EE32	Lo
1EE34	1EE37	Lo
1EE39		Lo
1EE3B		Lo
1EE42		Lo
1EE47		Lo
1EE49		Lo
1EE4B		Lo
1EE4D	1EE4F	Lo
1EE51	1EE52	Lo
1EE54		Lo
1EE57		Lo
1EE59		Lo
1EE5B		Lo
1EE5D		Lo
1EE5F		Lo
1EE61	1EE62	Lo
1EE64		Lo
1EE67	1EE6A	Lo
1EE6C	1EE72	Lo
1EE74	1EE77	Lo
1EE79	1EE7C	Lo
1EE7E		Lo
1EE80	1EE89	Lo
1EE8B	1EE9B	Lo
1EEA1	1EEA3	Lo
1EEA5	1EEA9	Lo
1EEAB	1EEBB	Lo
1EEF0	1EEF1	Sm
1F000	1F02B	So
1F030	1F093	So
1F0A0	1F0AE	So
1F0B1	1F0BF	So
1F0C1	1F0CF	So
1F0D1	1F0F5	So
1F100	1F10C	No
1F10D	1F1AD	So
1F1E6	1F202	So
1F210	1F23B	So
1F240	1F248	So
1F250	1F251	So
1F260	1F265	So
1F300	1F3FA	So
1F3FB	1F3FF	Sk
1F400	1F6D7	So
1F6DC	1F6EC	So
1F6F0	1F6FC	So
1F700	1F776	So
1F77B	1F7D9	So
1F7E0	1F7EB	So
1F7F0		So
1F800	1F80B	So
1F810	1F847	So
1F850	1F859	So
1F860	1F887	So
1F890	1F8AD	So
1F8B0	1F8B1	So
1F900	1FA53	So
1FA60	1FA6D	So
1FA70	1FA7C	So
1FA80	1FA88	So
1FA90	1FABD	So
1FABF	1FAC5	So
1FACE	1FADB	So
1FAE0	1FAE8	So
1FAF0	1FAF8	So
1FB00	1FB92	So
1FB94	1FBCA	So
1FBF0	1FBF9	Nd
20000	2A6DF	Lo
2A700	2B739	Lo
2B740	2B81D	Lo
2B820	2CEA1	Lo
2CEB0	2EBE0	Lo
2F800	2FA1D	Lo
30000	3134A	Lo
31350	323AF	Lo
E0001		Cf
E0020	E007F	Cf
E0100	E01EF	Mn
F0000	FFFFD	Co
100000	10FFFD	Co
END
