# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 15.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V52
4982
4983
8556
8557
8572
8573
8582
8583
12876
12877
12991
12992
65812
65813
65860
65861
65866
65867
65873
65874
65894
65898
65908
65909
66286
66287
66339
66340
68045
68046
68222
68223
68861
68862
69229
69230
69727
69728
70126
70127
71918
71919
72807
72808
74856
74857
119661
119662
126078
126079
126222
126223
END
