# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 15.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V32
160
161
847
848
860
867
3848
3849
3852
3853
3858
3859
4057
4059
6158
6159
7629
7630
7676
7677
8199
8200
8209
8210
8239
8240
78896
78903
78905
78908
94180
94181
END
